
.. highlight:: python
   :linenothreshold: 4

.. _sardana-screenshots:

============
Screenshots
============

Here you will find a host of example figures.

Sardana oriented graphical user interfaces
------------------------------------------

.. figure:: /_static/snapshot01.png
    :alt: TaurusGUI at work
    :width: 600

    TaurusGUI at work.

.. figure:: /_static/snapshot02.png
    :alt: TaurusGUI with synoptic and macro widget
    :width: 600
    
    TaurusGUI with synoptic and macro widget
  
.. figure:: /_static/snapshot03.png
    :alt: Spock console
    :width: 600
    
    Spock console
  
.. figure:: /_static/snapshot04.png
    :alt: TaurusGUI with synoptic and macro panel
    :width: 600

    TaurusGUI with synoptic and macro panel

.. _sardana-screenshots-guis:

Graphical user interface screen shots
-------------------------------------

.. figure:: /_static/gui_snapshot01.png
    :alt: ALBA_'s Storage ring GUI
    :width: 600
    
    ALBA_'s Storage ring GUI
  
.. figure:: /_static/gui_snapshot02.png
    :width: 600
    :alt: ALBA_'s LINAC to booster beam charge monitor GUI
    
    ALBA_'s LINAC to booster beam charge monitor GUI
  
.. figure:: /_static/gui_snapshot03.png
    :width: 600
    :alt: ALBA_'s beam position monitor GUI
    
    ALBA_'s beam position monitor GUI
  
.. figure:: /_static/gui_snapshot04.png
    :width: 600
    :alt: ALBA_'s Radio frequency plant GUI

    ALBA_'s Radio frequency plant GUI
  
.. figure:: /_static/gui_snapshot05.png
    :width: 600
    :alt: ALBA_'s tune excitation panel
    
    ALBA_'s tune excitation panel
  
.. figure:: /_static/gui_snapshot06.png
    :width: 600
    :alt: ALBA_'s fluorescent screen main panel
    
    ALBA_'s fluorescent screen main panel
  
.. figure:: /_static/gui_snapshot07.png
    :width: 600
    :alt: ALBA_'s front end GUI
    
    ALBA_'s front end GUI
  
.. figure:: /_static/gui_snapshot08.png
    :width: 600
    :alt: ALBA_'s digital low level radio frequency GUI
    
    ALBA_'s digital low level radio frequency GUI
  
.. figure:: /_static/gui_snapshot09.png
    :width: 600
    :alt: ALBA_'s vaccum GUI
    
    ALBA_'s vaccum GUI
  
.. figure:: /_static/gui_snapshot10.png
    :width: 600
    :alt: Sardana configuration GUI
    
    Sardana configuration GUI

.. _ALBA: http://www.cells.es/
.. _ANKA: http://http://ankaweb.fzk.de/
.. _ELETTRA: http://http://www.elettra.trieste.it/
.. _ESRF: http://www.esrf.eu/
.. _FRMII: http://www.frm2.tum.de/en/index.html
.. _HASYLAB: http://hasylab.desy.de/
.. _MAX-lab: http://www.maxlab.lu.se/maxlab/max4/index.html
.. _SOLEIL: http://www.synchrotron-soleil.fr/


.. _Tango: http://www.tango-controls.org/
.. _PyTango: http://packages.python.org/PyTango/
.. _Taurus: http://packages.python.org/taurus/
.. _QTango: http://www.tango-controls.org/download/index_html#qtango3
.. _Qt: http://qt.nokia.com/products/
.. _PyQt: http://www.riverbankcomputing.co.uk/software/pyqt/
.. _PyQwt: http://pyqwt.sourceforge.net/
.. _Python: http://www.python.org/
.. _IPython: http://ipython.org/
.. _ATK: http://www.tango-controls.org/Documents/gui/atk/tango-application-toolkit
.. _Qub: http://www.blissgarden.org/projects/qub/
.. _numpy: http://numpy.scipy.org/
.. _SPEC: http://www.certif.com/
.. _EPICS: http://www.aps.anl.gov/epics/
